task1_mareev_meledin
--------

This package is here to demonstrate the skill of creating packages.

To use, simply do: 

.. code:: python

        import import solve
        print(solve.nash_equilibrium([[1, 2], [3, 4]]))


Посмотрим на исходный код:
::

    Пример исходного кода

Create a JSON file containing your mappings and initialize the module

.. code:: python

    from ibmcloudenv import IBMCloudEnv
    IBMCloudEnv.init("/path/to/the/mappings/file/relative/to/prject/root")

